%%
%% RISP LaTeX class
%%
%% by Yasuteru Hosokawa (Ph.D.)
%%
%% Based on the original 1996 Jsp_e.sty by Xiao-Hong Sun (Ph.D.)
%%
%% 
\ProvidesClass{risp}[2020/01/09]
\typeout{risp.cls; Version 0.11 (UTF8)}
\NeedsTeXFormat{LaTeX2e}
\LoadClass[10pt,a4paper]{article}
\RequirePackage{wrapfig}
%
\@twosidetrue
\@mparswitchtrue
%%
%% page style
%%
\textwidth = 174 mm
\textheight = 241.5 mm
\oddsidemargin = -10mm
\evensidemargin = -11mm
\topmargin = -5 mm
\headheight = 2.5 mm
\headsep = 7 mm
\footskip = 0 mm
\unitlength = 1 mm
\parindent = 5 mm
\columnsep = 10 mm
\pagestyle{empty}%
%%
%% title page
%%
\def\TITLE#1{\gdef\@TITLE{#1}}
\def\TYPE#1{\gdef\@TYPE{\uppercase{\fontsize{12pt}{0pt}\selectfont #1}}}
\def\TITLE#1{\gdef\@TITLE{#1}}
\def\AUTHOR#1{\gdef\@AUTHOR{#1}}
\long\def\BELONG#1{\gdef\@BELONG{#1}}
\def\EMAIL#1{\gdef\@EMAIL{E-mail: #1}}
\long\def\ABSTRACT#1{\gdef\@ABSTRACT{#1}} 
\long\def\KEYWORDS#1{\gdef\@KEYWORDS{#1}}
%
\def\RECEIVED#1{\gdef\@RECEIVED{#1}}
\def\REVISED#1{\gdef\@REVISED{#1}}
%
\def\@TYPE{}
\def\@TITLE{}
\def\@AUTHOR{}
\def\@BELONG{}
\def\@EMAIL{}
\def\@ABSTRACT{}
\def\@KEYWORDS{}
%
\def\@RECEIVED{}
\def\@REVISED{}
%%
%% maketitle
%%
\def\maketitle{\par
\begingroup 
\if@twocolumn \twocolumn[\@maketitle] 
\else \newpage\global\@topnum\z@ \@maketitle \fi
\thispagestyle{empty}%
\endgroup
\let\maketitle\relax \let\@maketitle\relax}%
%
\def\@maketitle{\newpage\null
\vskip0.5em{\@TYPE}%
%
\vskip1em
{\baselineskip 8mm
 \begin{center}{\Large\bf\@TITLE}\end{center}}
%
\vskip1em
\begin{center}{\large\@AUTHOR}\end{center}
%
\vskip1em
\begin{center}
{\small \@BELONG \par \@EMAIL}
\end{center}
%
\vskip3em{\bf Abstract} \hskip1pc{\small\bf\@ABSTRACT}
\vskip1em{\bf Keywords:}\hskip0.4pc{\small\@KEYWORDS}
%
\vskip4em}%
%%
%% Figure
%%
\renewcommand{\figurename}{Fig.}
\long\def\@makecaption#1#2{%
\vskip\abovecaptionskip%
\sbox\@tempboxa{#1 \ \ #2}
\ifdim \wd\@tempboxa >\hsize%
#1 \ \ #2\par
\else
\global \@minipagefalse
\hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
\fi
\vskip\belowcaptionskip}
%%
%% section
%%
\def\section{\@startsection{section}{1}{\z@}%
{1\baselineskip plus 1mm minus 0.5mm}%
{1\baselineskip plus 1mm}{\bf\center{}}}%
%
\def\subsection{\@startsection{subsection}{2}{\z@}%
{1\baselineskip plus 1mm minus 0.5mm}%
%{1\baselineskip plus 1mm}{}}%
{1\baselineskip plus 1mm}{\bf{}}}%
%
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}%
{1\baselineskip plus 1mm minus 0.5mm}%
{0.01\baselineskip plus 1mm}{}}%
%
\def\thesection{\arabic{section}.}%
\def\thesubsection{\thesection{\arabic{subsection}}}%
%%
%% reference
%%
\def\thebibliography#1{%
 \section*{\begin{center}\bf References\end{center}}%
 \list{[\arabic{enumi}]}%
{\settowidth\labelwidth{[#1]}\leftmargin\labelwidth
 \advance\leftmargin\labelsep \usecounter{enumi}}%
 \setlength{\itemsep}{0pt}%
 \parskip 0mm
 \footnotesize
 \baselineskip 4mm
 \def\newblock{\hskip .11em plus .33em minus .07em}%
 \sloppy\clubpenalty4000\widowpenalty4000
 \sfcode`\.=1000\relax}%
\let\endthebibliography=\endlist
%%
%% profile
%%
\newlength{\hoge}
\long\def\PROFILE#1#2#3{%
\footnotesize
\noindent
\begin{minipage}[t]{1.0\columnwidth}% 8.2mm
\setlength\intextsep{0mm}
\settoheight{\hoge}{
  \begin{minipage}{3.5cm}
  \noindent{\bf #2}%
  \hskip0mm{#3}
  \end{minipage}
}
\ifdim\hoge>80pt
\setlength{\columnsep}{6mm}
    \begin{wrapfigure}[13]{l}[0pt]{30mm}
    %\begin{minipage}{3.5cm}
    \centering
    %\vspace*{4cm}
    \includegraphics[width=3cm,height=4cm]{#1}
    \end{wrapfigure}
    %\end{minipage}%
    %\begin{minipage}[t]{4.5cm}
    \noindent{\bf #2}%
    \hskip0mm{#3}
    %\end{minipage}%
\else
    \begin{minipage}[t]{3.5cm}
    \hspace{-2mm}
    \raisebox{-3.8cm}{
    \includegraphics[width=3cm,height=4cm]{#1}
    }
    \end{minipage}%
    \hspace{0mm}
    \begin{minipage}[t]{4.7cm}
    \noindent{\bf #2}%
    \hskip0mm{#3}
    \end{minipage}%
\fi
\end{minipage}%
\vspace{5mm}
}%
%%
%% received, resived
%%
\def\RECEIVEDDATE{\footnotesize{(Received \@RECEIVED; revised \@REVISED)}}
%
\twocolumn
\sloppy
\raggedbottom
